# matflow-defdap

[![PyPI version](https://img.shields.io/pypi/v/matflow_defdap.svg)](https://pypi.python.org/pypi/matflow_defdap)

Matflow extension for the Deformation Data Analysis in Python ([DefDAP](https://github.com/MechMicroMan/DefDAP)) package.

This extension generates Python scripts that require the following Python packages to be installed:

- [DefDAP](https://github.com/MechMicroMan/DefDAP)
- [hickle](https://github.com/telegraphic/hickle) (version >=4.0.1)
